@@ -31,10 +31,6 @@ try:
     import geopandas
 except (ImportError, AttributeError):  # pragma: NO COVER
     geopandas = None
-try:
-    import pyarrow
-except (ImportError, AttributeError):  # pragma: NO COVER
-    pyarrow = None
 try:
     from google.cloud import bigquery_storage
 except (ImportError, AttributeError):  # pragma: NO COVER
@@ -44,11 +40,15 @@ try:
 except (ImportError, AttributeError):  # pragma: NO COVER
     tqdm = None
 
+from google.cloud.bigquery import _helpers
 from .helpers import _make_client
 from .helpers import _make_connection
 from .helpers import _make_job_resource
 
 
+pyarrow = _helpers.PYARROW_VERSIONS.try_import()
+
+
 @pytest.fixture
 def table_read_options_kwarg():
     # Create a BigQuery Storage table read options object with pyarrow compression
